@@ -72,8 +72,8 @@ static const struct _classification {
     { "p10", CMS    |  Ascii  | CertificateRequest },
     { "p12", CMS    | Binary  | ExportedPSM },
     { "p7c", CMS    | Binary  | Certificate  },
-    { "p7m", CMS    | Binary  | CipherText },
-    { "p7s", CMS    | Binary  | AnySignature },
+    { "p7m", CMS    | AnyFormat | CipherText },
+    { "p7s", CMS    | AnyFormat | AnySignature },
     { "pem", CMS    |  Ascii  | AnyType | ExamineContentHint },
     { "pfx", CMS    | Binary  | Certificate },
     { "pgp", OpenPGP | Binary  | OpaqueSignature | CipherText | AnyCertStoreType | ExamineContentHint},
